@@ -3,8 +3,9 @@ from __future__ import annotations
 
 # Imports kept explicit and top-level
 import unittest
+from abc import ABC, abstractmethod
 from enum import Enum
-from typing import Optional, Union, Dict, List, Literal, TypedDict, Set, Tuple
+from typing import Optional, Union, Dict, List, Literal, TypedDict, Set, Tuple, NamedTuple, Type
 from pydantic import BaseModel
 
 # Import exception hierarchy from provider_manager to keep types consistent
@@ -21,6 +22,13 @@ class Message(TypedDict):
 Conversation = Union[str, List[Message]]
 
 
+class LlmResponse(NamedTuple):
+    """Response from LLM execution containing result, logs, and provider info"""
+    value: Union[str, BaseModel]  # The actual response value
+    output: str  # Complete log of execution (empty for most providers)
+    provider: str  # Name of the provider that was used
+
+
 # Define logical model sizes / tiers referenced across providers
 class ModelType(Enum):
     LOCAL_SMALL = "local_small"
@@ -142,7 +150,7 @@ def _resolve_model_name_for_ctor(
 
 
 # Unified interface for all providers, with flexible construction helpers
-class Llm:
+class Llm(ABC):
     # Cache instances by fully-qualified model name
     _cached: Dict[str, Llm] = {}
 
@@ -167,6 +175,7 @@ class Llm:
         # Store resolved name and parsed parts
         self.model_name = fq_name
         self.provider, self.model = ModelResolver.parse_model_name(fq_name)
+        self.provider_name = self.provider  # For compatibility with CLI interface
 
     # Construct using a provider's default model (camelCase per request)
     @classmethod
@@ -249,40 +258,46 @@ class Llm:
         """
         Get a CLI interface that provides enhanced logging capabilities
 
-        Returns an LlmCliMeta instance that automatically tries all available CLI providers
-        and captures comprehensive execution logs.
+        Returns a CLI provider instance with enhanced logging.
 
         Returns:
-            LlmCliMeta: Meta-provider with logging for codex, gemini, and claude CLIs
+            Llm: CLI provider with logging capabilities
         """
-        from .llm_cli_interface import LlmCliMeta
+        # Try to find and return the best available CLI provider with logging
+        try:
+            from .llm_cli_claude import LlmClaudeCliWithLogging
+            if LlmClaudeCliWithLogging.is_available():
+                return LlmClaudeCliWithLogging()
+        except ImportError:
+            pass
 
-        return LlmCliMeta()
+        # Add other CLI providers here as they get updated
+        raise ConfigurationError("No CLI providers with logging available")
 
-    # Send a chat conversation and return assistant text (subclasses must implement)
-    def chat(self, conversation: Conversation, force_json: bool = False) -> str:
+    # Send a chat conversation and return LlmResponse with result and logs
+    def chat(self, conversation: Conversation, force_json: bool = False) -> LlmResponse:
         """Synchronous wrapper that blocks on the async implementation."""
-        return _run_sync(self.async_chat(conversation, force_json))
+        return _run_sync(self.chat_async(conversation, force_json))
 
     # Async variant for non-blocking use in event loops
-    async def async_chat(self, conversation: Conversation, force_json: bool = False) -> str:
+    @abstractmethod
+    async def chat_async(self, conversation: Conversation, force_json: bool = False) -> LlmResponse:
         """Async chat that providers must implement."""
-        raise NotImplementedError("async_chat should be implemented by subclasses")
+        pass
 
     # Send a chat conversation and parse into a Pydantic schema (subclasses must implement)
     def chat_structured(
-        self, conversation: Conversation, schema: BaseModel, context_size: int = 0
-    ) -> BaseModel:
+        self, conversation: Conversation, schema: Type[BaseModel], context_size: int = 0
+    ) -> LlmResponse:
         """Synchronous wrapper that blocks on the async implementation."""
-        return _run_sync(self.async_chat_structured(conversation, schema, context_size))
+        return _run_sync(self.chat_structured_async(conversation, schema, context_size))
 
-    async def async_chat_structured(
-        self, conversation: Conversation, schema: BaseModel, context_size: int = 0
-    ) -> BaseModel:
+    @abstractmethod
+    async def chat_structured_async(
+        self, conversation: Conversation, schema: Type[BaseModel], context_size: int = 0
+    ) -> LlmResponse:
         """Async structured chat that providers must implement."""
-        raise NotImplementedError(
-            "async_chat_structured should be implemented by subclasses"
-        )
+        pass
 
     # Generate an image and return the output path/URL (subclasses must implement)
     def image(
@@ -291,45 +306,60 @@ class Llm:
         """Synchronous wrapper that blocks on the async implementation."""
         return _run_sync(self.async_image(prompt, file_name, width, height))
 
+    @abstractmethod
     async def async_image(
         self, prompt: str, file_name: str, width: int = 1024, height: int = 1024
     ) -> str:
         """Async image generation that providers must implement."""
-        raise NotImplementedError("async_image should be implemented by subclasses")
+        pass
 
     # Get context length for the current model (subclasses must implement)
+    @abstractmethod
     def get_context_length(self) -> int:
         """Get the context length (token limit) for the current model"""
-        raise NotImplementedError("get_context_length should be implemented by subclasses")
+        pass
 
     # Describe provider capabilities (subclasses must implement)
     @staticmethod
+    @abstractmethod
     def capabilities() -> Set[str]:
-        raise NotImplementedError("capabilities should be implemented by subclasses")
+        pass
 
     # List model ids supported by the provider (subclasses must implement)
     @staticmethod
+    @abstractmethod
     def supported_models() -> List[str]:
-        raise NotImplementedError(
-            "supported_models should be implemented by subclasses"
-        )
+        pass
 
     # Return the provider's default model id (subclasses must implement)
     @staticmethod
+    @abstractmethod
     def default_model() -> str:
-        raise NotImplementedError("default_model should be implemented by subclasses")
+        pass
 
     # Return the provider's default model id for a given type (subclasses must implement)
     @staticmethod
+    @abstractmethod
     def default_for_type(model_type: str) -> Optional[str]:
-        raise NotImplementedError(
-            "default_for_type should be implemented by subclasses"
-        )
+        pass
 
     # Verify provider-level configuration (subclasses must implement)
     @staticmethod
+    @abstractmethod
     def check_config():
-        raise NotImplementedError("check_config should be implemented by subclasses")
+        pass
+
+    # Check if this provider is available on the system
+    @classmethod
+    def is_available(cls) -> bool:
+        """Check if this provider is available on the system"""
+        try:
+            # Default implementation: try to call check_config
+            # Subclasses can override for more specific availability checks
+            cls.check_config()
+            return True
+        except Exception:
+            return False
 
     # Convenience: resolve and chat without manually constructing an instance
     @classmethod
@@ -339,7 +369,7 @@ class Llm:
         model: Optional[str] = None,
         model_type: Optional[ModelType] = None,
         force_json: bool = False,
-    ) -> str:
+    ) -> LlmResponse:
         from .model_resolver import ModelResolver
 
         model_name = ModelResolver.resolve_model(model, model_type)
@@ -347,30 +377,30 @@ class Llm:
         return llm.chat(conversation, force_json)
 
     @classmethod
-    async def async_chat_static(
+    async def chat_static_async(
         cls,
         conversation: Conversation,
         model: Optional[str] = None,
         model_type: Optional[ModelType] = None,
         force_json: bool = False,
-    ) -> str:
+    ) -> LlmResponse:
         """Async convenience chat using resolved model."""
         from .model_resolver import ModelResolver
 
         model_name = ModelResolver.resolve_model(model, model_type)
         llm = cls.model_named(model_name)
-        return await llm.async_chat(conversation, force_json)
+        return await llm.chat_async(conversation, force_json)
 
     # Convenience: resolve and structured-chat without manually constructing an instance
     @classmethod
     def chat_structured_static(
         cls,
         conversation: Conversation,
-        schema: BaseModel,
+        schema: Type[BaseModel],
         model: Optional[str] = None,
         model_type: Optional[ModelType] = None,
         context_size: int = 0,
-    ) -> BaseModel:
+    ) -> LlmResponse:
         from .model_resolver import ModelResolver
 
         model_name = ModelResolver.resolve_model(model, model_type)
