@@ -9,7 +9,7 @@ from typing import Type
 from pydantic import BaseModel
 from jsonschema import validate, ValidationError
 
-from .core import Llm, Conversation, ConfigurationError, DazLlmError, _run_sync
+from .core import Llm, Conversation, ConfigurationError, DazLlmError, _run_sync, LlmResponse
 import re
 
 
@@ -120,23 +120,15 @@ class LlmOllama(Llm):
         """Convert conversation to Ollama message format"""
         return [{"role": "user", "content": conversation}] if isinstance(conversation, str) else conversation
 
-    def chat(self, conversation: Conversation, force_json: bool = False) -> str:
-        """Sync wrapper; blocks on async_chat."""
-        return _run_sync(self.async_chat(conversation, force_json))
+    def chat(self, conversation: Conversation, force_json: bool = False) -> LlmResponse:
+        """Sync wrapper; blocks on chat_async."""
+        return _run_sync(self.chat_async(conversation, force_json))
 
     def chat_structured(
         self, conversation: Conversation, schema: Type[BaseModel], context_size: int = 0
-    ) -> BaseModel:
-        """Chat with structured output using Pydantic schema"""
-        messages = self._normalize_conversation(conversation)
-        schema_json = schema.model_json_schema()
-
-        if self._supports_format:
-            # Use the standard format parameter approach
-            return self._chat_structured_with_format(messages, schema, schema_json, context_size)
-        else:
-            # Use manual schema injection for models without format support
-            return self._chat_structured_without_format(messages, schema, schema_json, context_size)
+    ) -> LlmResponse:
+        """Sync wrapper; blocks on chat_structured_async."""
+        return _run_sync(self.chat_structured_async(conversation, schema, context_size))
 
     def _chat_structured_with_format(
         self, messages: list, schema: Type[BaseModel], schema_json: dict, context_size: int
@@ -204,7 +196,7 @@ class LlmOllama(Llm):
 
         raise DazLlmError("Failed to get valid structured response after multiple attempts")
 
-    async def async_chat(self, conversation: Conversation, force_json: bool = False) -> str:
+    async def chat_async(self, conversation: Conversation, force_json: bool = False) -> LlmResponse:
         import asyncio
         messages = self._normalize_conversation(conversation)
         data = {"model": self.model, "messages": messages, "stream": False}
@@ -215,7 +207,8 @@ class LlmOllama(Llm):
             try:
                 response = requests.post(f"{self.base_url}/api/chat", json=data, headers=self.headers, timeout=60)
                 response.raise_for_status()
-                return response.json()["message"]["content"]
+                content = response.json()["message"]["content"]
+                return LlmResponse(value=content, output="", provider=self.provider_name)
             except requests.exceptions.RequestException as e:  # noqa: BLE001
                 raise DazLlmError(f"Ollama API error: {e}") from e
             except KeyError as e:  # noqa: BLE001
@@ -223,11 +216,26 @@ class LlmOllama(Llm):
 
         return await asyncio.to_thread(_call_sync)
 
-    async def async_chat_structured(
+    async def chat_structured_async(
         self, conversation: Conversation, schema: Type[BaseModel], context_size: int = 0
-    ) -> BaseModel:
+    ) -> LlmResponse:
+        """Chat with structured output using Pydantic schema"""
         import asyncio
-        return await asyncio.to_thread(self.chat_structured, conversation, schema, context_size)
+
+        def _call_sync():
+            messages = self._normalize_conversation(conversation)
+            schema_json = schema.model_json_schema()
+
+            if self._supports_format:
+                # Use the standard format parameter approach
+                result = self._chat_structured_with_format(messages, schema, schema_json, context_size)
+            else:
+                # Use manual schema injection for models without format support
+                result = self._chat_structured_without_format(messages, schema, schema_json, context_size)
+
+            return LlmResponse(value=result, output="", provider=self.provider_name)
+
+        return await asyncio.to_thread(_call_sync)
 
     def _chat_structured_without_format(
         self, messages: list, schema: Type[BaseModel], schema_json: dict, context_size: int
@@ -379,6 +387,15 @@ class LlmOllama(Llm):
             )
         )
 
+    async def async_image(self, prompt: str, file_name: str, width: int = 1024, height: int = 1024) -> str:
+        """Async image generation using Ollama (not supported by default)"""
+        raise DazLlmError(
+            (
+                "Image generation not supported by Ollama. "
+                "Use OpenAI or other providers for image generation."
+            )
+        )
+
     def get_context_length(self) -> int:
         """Get the context length for the current Ollama model"""
         try:
